@@ -4,7 +4,7 @@ import json
 csv = pd.read_csv('id.csv')
 csv = csv.values.tolist()
 
-def get_id(n):
+def get_ids(n):
     id = []
     for i in range(n):
         temp = {}
